#
# NATs interface
# Copyright 2019 Canonical Ltd.  All rights reserved.
#

import json
import subprocess

from charms.reactive import Endpoint


class NatsRequires(Endpoint):
    def urls(self):
        if len(self.relations) is 0:
            return []
        urls = []
        for r in self.relations:
            for u in r.units:
                if not u or not u.received:
                    continue
                url = u.received.get('url')
                if url is not None:
                    urls += [u.received['url']]
        return urls

    # NOTE: As long as reactive does not have support for application data
    # we need to invoke the relation-get helper manually and extract the data
    def _relation_get_app_data(self, relation_id, remote_app_name):
        data = json.loads(subprocess.check_output(["relation-get", "--app", "-r", relation_id,
            "--format=json", "-", remote_app_name]))
        return data

    def ca_cert(self):
        if len(self.relations) == 0:
            return ""
        if len(self.relations) > 1:
            raise Exception("Cannot be related to multiple NATS applications at the same time")

        r = self.relations[0]
        data = self._relation_get_app_data(r.relation_id, r.application_name)
        if not 'ca_cert' in data:
            return ""
        return data['ca_cert']