#
# Anbox Stream Gateway
# Copyright 2019 Canonical Ltd.  All rights reserved.
#

import os

from charmhelpers.core.hookenv import log
from charmhelpers.core.unitdata import kv
from charms.reactive import (when, set_flag,
                             clear_flag, endpoint_from_flag)

from reactive.gateway import SERVICE_PATH
NATS_TLS_CA_CERT_PATH = '{}/nats_ca.pem'.format(SERVICE_PATH)


"""
Flags:
 - nats.configured: set when NATS is ready to be used
"""


@when('endpoint.nats.changed', 'anbox-stream-gateway.installed')
def nats_changed(_):
    nats = endpoint_from_flag('endpoint.nats.changed')

    if not nats or nats.urls() is None or len(nats.urls()) == 0:
        kv().set('nats_config', None)
        log("NATs endpoint is not available", level='WARNING')
        return

    nats_cfg = {'endpoints': nats.urls()}

    nats_ca_cert = nats.ca_cert()
    if nats_ca_cert is not None and len(nats_ca_cert) > 0:
        with open(os.open(NATS_TLS_CA_CERT_PATH, os.O_CREAT | os.O_WRONLY, 0o600), "w+") as f:
            f.write(nats_ca_cert)
        nats_cfg['tls'] = {'ca': NATS_TLS_CA_CERT_PATH}

    kv().set('nats_config', nats_cfg)
    set_flag('gateway.changed')

    set_flag('nats.configured')
    clear_flag('endpoint.nats.changed')


@when('endpoint.nats.departed', 'anbox-stream-gateway.installed')
def nats_departed(_):
    kv().set('nats_config', None)
    set_flag('gateway.changed')
    clear_flag('nats.configured')
    clear_flag('endpoint.nats.departed')
